<?php

namespace Drupal\viewfield_argument_helper\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Class LookupController.
 */
class LookupController extends ControllerBase {

  /**
   * Lookup service.
   *
   * @var \Drupal\viewfield_argument_helper\Lookup
   */
  protected $viewfieldArgumentAutocompleteLookup;

  /**
   * Renderer service.
   *
   * @var \Drupal\Core\Renderer
   */
  protected $renderer;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->viewfieldArgumentAutocompleteLookup = $container->get('viewfield_argument_helper.lookup');
    $instance->renderer = $container->get('renderer');
    return $instance;
  }

  /**
   * Lookup.
   */
  public function lookup(Request $request, $view_id, $display_id) {
    $slots = $this->viewfieldArgumentAutocompleteLookup->getArgumentOptions($view_id, $display_id);

    $element = [];
    $slot_count = 0;
    foreach ($slots as $sid => $slot) {
      $opts = $slot['options'];
      $name = $slot['name'];
      $slot_count++;
      $element['slot_' . $sid] = [
        '#type' => 'details',
        '#title' => sprintf('Slot %d: %s', $slot_count, $name),
        '#attributes' => [
          'class' => [
            'vaa-slot-details',
          ],
        ],
      ];
      $element['slot_' . $sid]['options'] = [
        '#type' => 'table',
        '#attributes' => [
          'class' => [
            'vaa-lookup-table',
          ],
        ],
        '#header' => [
          'ID',
          'Label',
          'Bundle',
        ],
      ];
      foreach (array_values($opts) as $i => $opt) {
        $element['slot_' . $sid]['options'][$i]['id'] = [
          '#plain_text' => $opt['id'],
          '#title' => 'ID',
        ];
        $element['slot_' . $sid]['options'][$i]['label'] = [
          '#plain_text' => $opt['label'],
          '#title' => 'Label',
        ];
        $element['slot_' . $sid]['options'][$i]['bundle'] = [
          '#plain_text' => $opt['bundle'],
          '#title' => 'Bundle',
        ];
      }
    }

    // Allow other modules to alter the element.
    $context = [
      'view_id' => $view_id,
      'display_id' => $display_id,
      'options' => $opts,
    ];
    $this->moduleHandler()->alter('viewfield_argument_helper_lookup_element', $element, $context);

    return new JsonResponse([
      'markup' => $this->renderer->render($element),
      'slot_counts' => array_map('count', $slots),
    ]);
  }

  /**
   * Get information about the slots for initialization.
   */
  public function slotInfo(Request $request, $view_id, $display_id) {
    $slots = $this->viewfieldArgumentAutocompleteLookup->getArgumentOptions($view_id, $display_id);
    return new JsonResponse($slots);
  }

  /**
   * Autocomplete for viewfield argument slots.
   */
  public function autocomplete(Request $request, $view_id, $display_id, $slot_id) {
    $slots = $this->viewfieldArgumentAutocompleteLookup->getArgumentOptions($view_id, $display_id);
    $slot = NULL;
    foreach ($slots as $s) {
      if ($s['id'] == $slot_id) {
        $slot = $s;
        break;
      }
    }
    if (!$slot) {
      return new JsonResponse(['error' => 'Slot not found'], 404);
    }

    $opts = array_values(array_map(function ($opt) {
      return [
        'value' => $opt['id'],
        'label' => $opt['label'],
      ];
    }, $slot['options']));

    // Allow other modules to alter the options.
    $context = [
      'view_id' => $view_id,
      'display_id' => $display_id,
      'slot_id' => $slot_id,
      'def' => $slot,
    ];
    $this->moduleHandler()->alter('viewfield_argument_helper_autocomplete_options', $opts, $context);

    return new JsonResponse($opts);
  }

}
