<?php

declare(strict_types=1);

namespace Drupal\viewfield_argument_helper\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Viewfield Argument Helper settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'viewfield_argument_helper_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['viewfield_argument_helper.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['default_widget'] = [
      '#type' => 'select',
      '#title' => $this->t('Default Viewfield Argument Helper Widget Type'),
      '#default_value' => $this->config('viewfield_argument_helper.settings')->get('default_widget'),
      '#options' => [
        'lookup' => $this->t('Lookup (legacy)'),
        'autocomplete' => $this->t('Autocomplete'),
      ],
      '#description' => $this->t('Select the default widget type for the Viewfield Argument Helper. This will be used when no specific widget type is set for a Viewfield field.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('viewfield_argument_helper.settings')
      ->set('default_widget', $form_state->getValue('default_widget'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
