<?php

/**
 * @file
 * Hook demos.
 */

/**
 * Alter entity type support by a particular argument plugin.
 *
 * @param string $entity_type Entity ID, like 'node'
 * @param array  $context Context array:
 *   [
 *     'argument_plugin' => Views argument object,
 *     'view_id'         => View ID,
 *     'display_id'      => View display ID,
 *     'slot_count'      => Argument numbering, 0..n,
 *   ]
 */
function hook_viewfield_argument_helper_entity_type_alter(string &$entity_type, array $context) {
  if ($context['view_id'] == 'events' && $context['display_id'] == 'block_1') {
    $entity_type = 'taxonomy_term';
  }
}

/**
 * Alter bundles allowed by a particular argument plugin.
 *
 * @param array  $bundles Entity bundles queried by lookup, defaulting to argument validator settings
 * @param array  $context Context array:
 *   [
 *     'argument_plugin' => Views argument object,
 *     'view_id'         => View ID,
 *     'display_id'      => View display ID,
 *     'slot_count'      => Argument numbering, 0..n
 *   ]
 */
function hook_viewfield_argument_helper_bundles_alter(array &$bundles, array $context) {
  if ($context['view_id'] == 'news_and_events') {
    unset($bundles['page']);
  }
}

/**
 * Alter entity options returned by the lookup.
 *
 * @param array $entities Entities returned by a lookup for an argument.
 * @param array $context Context array:
 *   [
 *     'argument_plugin' => Views argument object,
 *     'view_id'         => View ID,
 *     'display_id'      => View display ID,
 *     'slot_count'      => Argument numbering, 0..n,
 *   ]
 */
function hook_viewfield_argument_helper_entities_alter(array &$entities, array $context) {
  // For first argument for an events listing, ignore argument specs and load up a list of event_tags taxonomy terms.
  if ($context['view_id'] == 'events' && $context['slot_count'] == 0) {
    $entities = \Drupal::entityTypeManager()
      ->getStorage('taxonomy_term')
      ->loadByProperties([
        'vid' => 'event_tags',
      ]);
  }
}

/**
 * Alter the element for a Viewfield argument lookup.
 * 
 * @param array $element Element to alter, like:
 *   [
 *     '#type' => 'details',
 *     '#title' => 'Slot 1: Event Tags',    
 *   ]
 * @param array $context Context array:
 *   [
 *     'view_id'    => View ID,
 *     'display_id' => View display ID,
 *     'options'    => Options array
 *   ]
 */
function hook_viewfield_argument_helper_lookup_element_alter(array &$element, array $context) {
  // For first argument for an events listing, rewrite the title and description.
  if ($context['view_id'] == 'events' && $context['display_id'] == 'block_1') {
    $element['#title'] = t('Event Tags');
    $element['#description'] = t('Select event tags to filter the events listing.');
  }
}

/**
 * Alter autocomplete options for a Viewfield argument.
 * 
 * @param array $options Autocomplete options, like:
 *   [
 *     ['value' => '1', 'label' => 'Label 1'],
 *     ['value' => '2', 'label' => 'Label 2'],
 *   ]
 * @param array $context Context array:
 *   [
 *     'view_id'    => View ID,
 *     'display_id' => View display ID,
 *     'slot_id'    => Argument slot ID, 0..n
 *   ]
 */
function hook_viewfield_argument_helper_autocomplete_options_alter(array &$options, array $context) {
  // For first argument for an events listing, ignore argument specs and load up a list of event_tags taxonomy terms.
  if ($context['view_id'] == 'events' && $context['slot_id'] == 0) {
    $options = \Drupal::entityTypeManager()
      ->getStorage('taxonomy_term')
      ->loadByProperties([
        'vid' => 'event_tags',
      ]);
    $options = array_map(function ($term) {
      return [
        'id' => $term->id(),
        'label' => $term->label(),
        'bundle' => $term->bundle(),
      ];
    }, $options);
  }
}

